@@ -31,12 +31,12 @@ WWW::Shorten::Bitly - Interface to shortening URLs using L<http://bit.ly>
 
 =head1 VERSION
 
-$Revision: 110 $
+$Revision: 1.11 $
 
 =cut
 
 BEGIN {
-    our $VERSION = do { my @r = (q$Revision: 1.10 $ =~ /\d+/g); sprintf "%1d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+    our $VERSION = do { my @r = (q$Revision: 1.11 $ =~ /\d+/g); sprintf "%1d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
     $WWW::Shorten::Bitly::VERBOSITY = 2;
 }
 
@@ -45,41 +45,41 @@ BEGIN {
 
 =head1 SYNOPSIS
 
-WWW::Shorten::Bitly provides an easy interface for shortening URLs using http://bit.ly.  In addition to shortening URLs, you can pull statistics that bit.ly gathers regarding each shortened
+WWW::Shorten::Bitly provides an easy interface for shortening URLs using http://bit.ly. In addition to shortening URLs, you can pull statistics that bit.ly gathers regarding each shortened
 WWW::Shorten::Bitly uses XML::Simple to convert the xml response for the meta info and click stats to create a hashref of the results.
 
-WWW::Shorten::Bitly provides two interfaces.  The first is the common C<makeashorterlink> and C<makealongerlink> that WWW::Shorten provides.  However, due to the way the bit.ly API works, additional arguments are required.  The second provides a better way of retrieving additional information and statistics about a bit.ly URL.
+WWW::Shorten::Bitly provides two interfaces. The first is the common C<makeashorterlink> and C<makealongerlink> that WWW::Shorten provides. However, due to the way the bit.ly API works, additional arguments are required. The second provides a better way of retrieving additional information and statistics about a bit.ly URL.
 
-    use WWW::Shorten::Bitly;
+use WWW::Shorten::Bitly;
 
-    my $url = "http://www.example.com";
+my $url = "http://www.example.com";
 
-    my $tmp = makeashorterlink($url, 'MY_BITLY_USERNAME', 'MY_BITLY_API_KEY');
-    my $tmp1 = makealongerlink($tmp, 'MY_BITLY_USERNAME', 'MY_BITLY_API_KEY');
+my $tmp = makeashorterlink($url, 'MY_BITLY_USERNAME', 'MY_BITLY_API_KEY');
+my $tmp1 = makealongerlink($tmp, 'MY_BITLY_USERNAME', 'MY_BITLY_API_KEY');
 
 or
 
-    use WWW::Shorten::Bitly;
+use WWW::Shorten::Bitly;
 
-    my $url = "http://www.example.com";
-    my $bitly = WWW::Shorten::Bitly->new(URL   => $url,
-                                        USER   => "my_user_id",
-                                        APIKEY => "my_api_key");
+my $url = "http://www.example.com";
+my $bitly = WWW::Shorten::Bitly->new(URL => $url,
+USER => "my_user_id",
+APIKEY => "my_api_key");
 
-    $bitly->shorten(URL => $url);
-    print "shortened URL is $bitly->{bitlyurl}\n";
+$bitly->shorten(URL => $url);
+print "shortened URL is $bitly->{bitlyurl}\n";
 
-    $bitly->expand(URL => $bitly->{bitlyurl});
-    print "expanded/original URL is $bitly->{longurl}\n";
+$bitly->expand(URL => $bitly->{bitlyurl});
+print "expanded/original URL is $bitly->{longurl}\n";
 
-    my $info = $bitly->info();
-    say "City referred to is " . $info->{calais}->{city}->{item};
-    say "Companies referred to are " . $info->{calais}->{company}->{item}[0] . "and " . $info->{calais}->{company}->{item}[1];
-    say "Title of the page is " . $info->{htmlTitle};
+my $info = $bitly->info();
+say "City referred to is " . $info->{calais}->{city}->{item};
+say "Companies referred to are " . $info->{calais}->{company}->{item}[0] . "and " . $info->{calais}->{company}->{item}[1];
+say "Title of the page is " . $info->{htmlTitle};
 
-    my $clicks = $bitly->clicks();
-    say "Total number of clicks received: " . $clicks->{clicks};
-    say "Total number of direct clicks received are: " . ${$clicks->{referrers}->{nodeKeyVal}[0]}->{direct}
+my $clicks = $bitly->clicks();
+say "Total number of clicks received: " . $clicks->{clicks};
+say "Total number of direct clicks received are: " . ${$clicks->{referrers}->{nodeKeyVal}[0]}->{direct}
 
 =head1 FUNCTIONS
 
@@ -87,26 +87,36 @@ or
 
 Create a new bit.ly object using your bit.ly user id and bit.ly api key.
 
-my $bitly = WWW::Shorten::Bitly->new(URL  => "http://www.example.com/this_is_one_example.html",
-                                     USER => "bitly_user_id",
-                                     APIKEY => "bitly_api_key");
+my $bitly = WWW::Shorten::Bitly->new(URL => "http://www.example.com/this_is_one_example.html",
+USER => "bitly_user_id",
+APIKEY => "bitly_api_key");
 
 =cut
 
 sub new {
     my ($class) = shift;
-    my %args    = @_;
+    my %args = @_;
     $args{source} ||= "perlteknatusbitly";
+    use File::Spec;
+    my $bitlyrc = $^O =~/Win32/i ? File::Spec->catfile($ENV{HOME}, "_bitly") : File::Spec->catfile($ENV{HOME}, ".bitly");
+    if (-r $bitlyrc){
+        open my $fh, "<", $bitlyrc or die "can't open .bitly file $!";
+        while(<$fh>){
+            $args{USER} ||= $1 if m{^USER=(.*)};
+            $args{APIKEY} ||= $1 if m{^APIKEY=(.*)};
+        }
+        close $fh;
+    }
     if (!defined $args{USER} || !defined $args{APIKEY}) {
         carp("USER and APIKEY are both required parameters.\n");
         return -1;
     }
     my $bitly;
-    $bitly->{USER}     = $args{USER};
-    $bitly->{APIKEY}   = $args{APIKEY};
-    $bitly->{json}     = JSON::Any->new;
-    $bitly->{browser}   = LWP::UserAgent->new(agent => $args{source});
-    $bitly->{xml}   = new XML::Simple(SuppressEmpty => 1);
+    $bitly->{USER} = $args{USER};
+    $bitly->{APIKEY} = $args{APIKEY};
+    $bitly->{json} = JSON::Any->new;
+    $bitly->{browser} = LWP::UserAgent->new(agent => $args{source});
+    $bitly->{xml} = new XML::Simple(SuppressEmpty => 1);
     my ($self) = $bitly;
     bless $self, $class;
 }
@@ -131,10 +141,16 @@ sub makeashorterlink #($;%)
     }
     my $ua = __PACKAGE__->ua();
     my $bitly;
-    $bitly->{json}     = JSON::Any->new;
-    $bitly->{xml}   = new XML::Simple(SuppressEmpty => 1);
-    my $biturl = "http://api.bit.ly/shorten?history=1&version=2.0.1&longUrl=" . $url . "&login=" . $user . "&apiKey=" . $apikey;
-    $bitly->{response} = $ua->get($biturl);
+    $bitly->{json} = JSON::Any->new;
+    $bitly->{xml} = new XML::Simple(SuppressEmpty => 1);
+    my $biturl = "http://api.bit.ly/shorten";
+    $bitly->{response} = $ua->post($biturl, [
+        'history' => '1',
+        'version' => '2.0.1',
+        'longUrl' => $url,
+        'login' => $user,
+        'apiKey' => $apikey,
+    ]);
     $bitly->{response}->is_success || die 'Failed to get bit.ly link: ' . $bitly->{response}->status_line;
     $bitly->{bitlyurl} = $bitly->{json}->jsonToObj($bitly->{response}->{_content})->{results}->{$url}->{shortUrl};
     return unless $bitly->{response}->is_success;
@@ -145,7 +161,7 @@ sub makeashorterlink #($;%)
 
 The function C<makealongerlink> does the reverse. C<makealongerlink>
 will accept as an argument either the full bit.ly URL or just the
-bit.ly identifier.  bit.ly requires the use of a user name and API
+bit.ly identifier. bit.ly requires the use of a user name and API
 Key when using the API.
 
 If anything goes wrong, then the function will return C<undef>.
@@ -159,41 +175,51 @@ sub makealongerlink #($,%)
     my $ua = __PACKAGE__->ua();
     my $bitly;
     my @foo = split(/\//, $url);
-    $bitly->{json}     = JSON::Any->new;
-    $bitly->{xml}   = new XML::Simple(SuppressEmpty => 1);
-    my $biturl = URI->new('http://api.bit.ly/expand?version=2.0.1&shortUrl=' . $url . '&login=' . $user . '&apiKey=' . $apikey);
-    $bitly->{response} = $ua->get($biturl);
-    $bitly->{response}->is_success || die 'Failed to get long bit.ly link: ' . $bitly->{response}->status_line;
+    $bitly->{json} = JSON::Any->new;
+    $bitly->{xml} = new XML::Simple(SuppressEmpty => 1);
+    $bitly->{response} = $ua->post('http://api.bit.ly/expand', [
+        'version' => '2.0.1',
+        'shortUrl' => $url,
+        'login' => $user,
+        'apiKey' => $apikey,
+    ]);
+    $bitly->{response}->is_success || die 'Failed to get bit.ly link: ' . $bitly->{response}->status_line;
     $bitly->{longurl} = $bitly->{json}->jsonToObj($bitly->{response}->{_content})->{results}->{$foo[3]}->{longUrl};
     return undef unless $bitly->{response}->is_success;
     my $content = $bitly->{response}->content;
-#    return undef if $content eq 'ERROR';
+# return undef if $content eq 'ERROR';
     return $bitly->{longurl};
 }
 
 =head2 shorten
 
-Shorten a URL using http://bit.ly.  Calling the shorten method will return the shortened URL but will also store it in bit.ly object until the next call is made.
+Shorten a URL using http://bit.ly. Calling the shorten method will return the shortened URL but will also store it in bit.ly object until the next call is made.
 
-    my $url = "http://www.example.com";
-    my $shortstuff = $bitly->shorten(URL => $url);
+my $url = "http://www.example.com";
+my $shortstuff = $bitly->shorten(URL => $url);
 
-    print "biturl is " . $bitly->{bitlyurl} . "\n";
+print "biturl is " . $bitly->{bitlyurl} . "\n";
 or
-    print "biturl is $shortstuff\n";
+print "biturl is $shortstuff\n";
 
 =cut
 
 
 sub shorten {
-    my $self  = shift;
-    my %args  = @_;
+    my $self = shift;
+    my %args = @_;
     if (!defined $args{URL}) {
         croak("URL is required.\n");
         return -1;
     }
-    $self->{short}   = "http://api.bit.ly/shorten?history=1&version=2.0.1&longUrl=" . $args{URL} ."&login=" . $self->{USER} . "&apiKey=" . $self->{APIKEY};
-    $self->{response} = $self->{browser}->get($self->{short});
+    $self->{response} = $self->{browser}->post('http://api.bit.ly/shorten', [
+        'history' => '1',
+        'version' => '2.0.1',
+        'longUrl' => $args{URL},
+        'login' => $self->{USER},
+        'apiKey' => $self->{APIKEY},
+    ]);
+    $self->{response}->is_success || die 'Failed to get bit.ly link: ' . $self->{response}->status_line;
     return undef if ( $self->{json}->jsonToObj($self->{response}->{_content})->{errorCode} != 0 );
     $self->{bitlyurl} = $self->{json}->jsonToObj($self->{response}->{_content})->{results}->{$args{URL}}->{shortUrl};
     return $self->{bitlyurl} if ( $self->{json}->jsonToObj($self->{response}->{_content})->{errorCode} == 0 );
@@ -205,15 +231,21 @@ Expands a shortened bit.ly URL to the original long URL.
 
 =cut
 sub expand {
-    my $self  = shift;
-    my %args  = @_;
+    my $self = shift;
+    my %args = @_;
     if (!defined $args{URL}) {
         croak("URL is required.\n");
         return -1;
     }
     my @foo = split(/\//, $args{URL});
-    $self->{short}   = "http://api.bit.ly/expand?history=1&version=2.0.1&shortUrl=" . $args{URL} ."&login=" . $self->{USER} . "&apiKey=" . $self->{APIKEY};
-    $self->{response} = $self->{browser}->get($self->{short});
+    $self->{response} = $self->{browser}->get('http://api.bit.ly/expand', [
+        'history' => '1',
+        'version' => '2.0.1',
+        'shortUrl' => $args{URL},
+        'login' => $self->{USER},
+        'apiKey' => $self->{APIKEY},
+    ]);
+    $self->{response}->is_success || die 'Failed to get bit.ly link: ' . $self->{response}->status_line;
     return undef if ( $self->{json}->jsonToObj($self->{response}->{_content})->{errorCode} != 0 );
     $self->{longurl} = $self->{json}->jsonToObj($self->{response}->{_content})->{results}->{$foo[3]}->{longUrl};
     return $self->{longurl} if ( $self->{json}->jsonToObj($self->{response}->{_content})->{errorCode} == 0 );
@@ -221,22 +253,28 @@ sub expand {
 
 =head2 info
 
-Get info about a shortened bit.ly URL.  By default, the method will use the value that's stored in $bitly->{bitlyurl}.  To be sure you're getting info on the correct URL, it's a good idea to set this value before getting any info on it.
+Get info about a shortened bit.ly URL. By default, the method will use the value that's stored in $bitly->{bitlyurl}. To be sure you're getting info on the correct URL, it's a good idea to set this value before getting any info on it.
 
-    $bitly->{bitlyurl} = "http://bit.ly/jmv6";
-    my $info = $bitly->info();
+$bitly->{bitlyurl} = "http://bit.ly/jmv6";
+my $info = $bitly->info();
 
-    say "City referred to is " . $info->{calais}->{city}->{item};
-    say "Companies referred to are " . $info->{calais}->{company}->{item}[0] . "and " . $info->{calais}->{company}->{item}[1];
-    say "Title of the page is " . $info->{htmlTitle};
+say "City referred to is " . $info->{calais}->{city}->{item};
+say "Companies referred to are " . $info->{calais}->{company}->{item}[0] . "and " . $info->{calais}->{company}->{item}[1];
+say "Title of the page is " . $info->{htmlTitle};
 
 
 =cut
 
 sub info {
     my $self = shift;
-    my $base = "http://api.bit.ly/info?format=xml&version=2.0.1&shortUrl=" . $self->{bitlyurl} . "&login=" . $self->{USER} . "&apiKey=" . $self->{APIKEY};
-    $self->{response} = $self->{browser}->get($base);
+    $self->{response} = $self->{browser}->post('http://api.bit.ly/info', [
+        'format' => 'xml',
+        'version' => '2.0.1',
+        'shortUrl' => $self->{bitlyurl},
+        'login' => $self->{USER},
+        'apiKey' => $self->{APIKEY},
+    ]);
+    $self->{response}->is_success || die 'Failed to get bit.ly link: ' . $self->{response}->status_line;
     $self->{$self->{bitlyurl}}->{content} = $self->{xml}->XMLin($self->{response}->{_content});
     $self->{$self->{bitlyurl}}->{errorCode} = $self->{$self->{bitlyurl}}->{content}->{errorCode};
     if ($self->{$self->{bitlyurl}}->{errorCode} == 0 ) {
@@ -249,20 +287,26 @@ sub info {
 
 =head2 clicks
 
-Get click thru information for a shortened bit.ly URL.  By default, the method will use the value that's stored in $bitly->{bitlyurl}.  To be sure you're getting info on the correct URL, it's a good idea to set this value before getting any info on it.
+Get click thru information for a shortened bit.ly URL. By default, the method will use the value that's stored in $bitly->{bitlyurl}. To be sure you're getting info on the correct URL, it's a good idea to set this value before getting any info on it.
 
-    $bitly->{bitlyurl} = "http://bit.ly/jmv6";
-    my $clicks = $bitly->clicks();
+$bitly->{bitlyurl} = "http://bit.ly/jmv6";
+my $clicks = $bitly->clicks();
 
-    say "Total number of clicks received: " . $clicks->{clicks};
-    say "Total number of direct clicks received are: " . ${$clicks->{referrers}->{nodeKeyVal}[0]}->{direct}
+say "Total number of clicks received: " . $clicks->{clicks};
+say "Total number of direct clicks received are: " . ${$clicks->{referrers}->{nodeKeyVal}[0]}->{direct}
 
 =cut
 
 sub clicks {
     my $self = shift;
-    my $base = "http://api.bit.ly/stats?format=xml&version=2.0.1&shortUrl=" . $self->{bitlyurl} . "&login=" . $self->{USER} . "&apiKey=" . $self->{APIKEY};
-    $self->{response} = $self->{browser}->get($base);
+    $self->{response} = $self->{browser}->post('http://api.bit.ly/stats', [
+        'format' => 'xml',
+        'version' => '2.0.1',
+        'shortUrl' => $self->{bitlyurl},
+        'login' => $self->{USER},
+        'apiKey' => $self->{APIKEY},
+    ]);
+    $self->{response}->is_success || die 'Failed to get bit.ly link: ' . $self->{response}->status_line;
     $self->{$self->{bitlyurl}}->{content} = $self->{xml}->XMLin($self->{response}->{_content});
     $self->{$self->{bitlyurl}}->{errorCode} = $self->{$self->{bitlyurl}}->{content}->{errorCode};
     if ($self->{$self->{bitlyurl}}->{errorCode} == 0 ) {
@@ -279,8 +323,12 @@ sub clicks {
 
 sub errors {
     my $self = shift;
-    my $base = "http://api.bit.ly/errors?version=2.0.1&login=" . $self->{USER} . "&apiKey=" . $self->{APIKEY};
-    $self->{response} = $self->{browser}->get($base);
+    $self->{response} = $self->{browser}->post('http://api.bit.ly/errors', [
+        'version' => '2.0.1',
+        'login' => $self->{USER},
+        'apiKey' => $self->{APIKEY},
+    ]);
+    $self->{response}->is_success || die 'Failed to get bit.ly link: ' . $self->{response}->status_line;
     $self->{$self->{bitlyurl}}->{content} = $self->{xml}->XMLin($self->{response}->{_content});
     $self->{$self->{bitlyurl}}->{errorCode} = $self->{$self->{bitlyurl}}->{content}->{errorCode};
     if ($self->{$self->{bitlyurl}}->{errorCode} == 0 ) {
@@ -297,13 +345,23 @@ Gets the module version number
 
 =cut
 sub version {
-    my $self     = shift;
+    my $self = shift;
     my($version) = shift;# not sure why $version isn't being set. need to look at it
     warn "Version $version is later then $WWW::Shorten::Bitly::VERSION. It may not be supported" if (defined ($version) && ($version > $WWW::Shorten::Bitly::VERSION));
     return $WWW::Shorten::Bitly::VERSION;
 }#version
 
 
+=head1 FILES
+
+$HOME/.bitly or _bitly on Windows Systems.
+
+You may omit USER and APIKEY in the constructor if you set them in the .bitly config file on separate lines using the syntax:
+
+USER=username
+APIKEY=apikey
+
+
 =head1 AUTHOR
 
 Pankaj Jain, C<< <pjain at cpan.org> >>
@@ -311,7 +369,7 @@ Pankaj Jain, C<< <pjain at cpan.org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-www-shorten-bitly at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Shorten-Bitly>.  I will
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Shorten-Bitly>. I will
 be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 
@@ -319,7 +377,7 @@ be notified, and then you'll automatically be notified of progress on your bug a
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc WWW::Shorten::Bitly
+perldoc WWW::Shorten::Bitly
 
 
 You can also look for information at:
@@ -353,6 +411,8 @@ L<http://search.cpan.org/dist/WWW-Shorten-Bitly/>
 
 =item Larry Wall, Damian Conway, and all the amazing folks giving us Perl and
 continuing to work on it over the years.
+=item Mizar, C<< <mizar.jp@gmail.com> >>, Peter Edwards, C<<pedwards@cpan.org> >>, Joerg Meltzer, C<< <joerg@joergmeltzer.de> >> for great patches.
+
 
 =back
 
@@ -362,7 +422,7 @@ continuing to work on it over the years.
 
 =item Copyright (c) 2009 Pankaj Jain, All Rights Reserved L<http://blog.linosx.com>.
 
-=item Copyright (c) 2009 Teknatus Solutions Private Limited, All Rights Reserved
+=item Copyright (c) 2009 Teknatus Solutions LLC, All Rights Reserved
 L<http://www.teknatus.com>.
 
 =back
